skir_client library

Classes

ArrayDescriptor
🪞 Describes an array type.
BoolDescriptor
🪞 Describes the bool primitive type.
BytesDescriptor
🪞 Describes the bytes primitive type.
ByteString
An immutable array of bytes.
EnumConstantVariant
🪞 Describes an enum constant variant.
EnumDescriptor
🪞 Describes a skir enum.
EnumSerializer<Enum>
Specialization of a Serializer for generated enum types.
EnumVariant
🪞 Describes a variant in an enum.
EnumWrapperVariant
🪞 Describes an enum wrapper variant.
FieldOrVariant
🪞 Describes a field in a struct or a variant in an enum.
Float32Descriptor
🪞 Describes the float32 primitive type.
Float64Descriptor
🪞 Describes the float64 primitive type.
Hash64Descriptor
🪞 Describes the hash64 primitive type.
Int32Descriptor
🪞 Describes the int32 primitive type.
Int64Descriptor
🪞 Describes the int64 primitive type.
internal__EnumSerializerBuilder<Enum>
internal__MutableList<E>
internal__StructSerializerBuilder<Frozen, Mutable>
internal__UnrecognizedFields
internal__UnrecognizedVariant
KeyedIterable<E, K>
An immutable iterable that supports fast lookup by key through findByKey.
Method<Request, Response>
Represents a remote procedure call (RPC) method definition.
MethodErrorInfo<RequestMeta>
Information about an error thrown during the execution of a method on the server side.
NoopReflectiveTypeVisitor<T>
🪞 A no-op implementation of ReflectiveTypeVisitor that does nothing for each visit method.
OptionalDescriptor
🪞 Describes an optional type that can hold either a value of the wrapped type or null.
PrimitiveDescriptor<T>
🪞 Describes a primitive skir type.
RawResponse
Raw response returned by the server.
RecordDescriptor
🪞 Describes a record type (struct or enum).
ReflectiveArrayDescriptor<E, Collection extends Iterable<E>>
🪞 Describes an array type.
ReflectiveEnumConstantVariant<E>
🪞 Describes an enum constant variant.
ReflectiveEnumDescriptor<E>
🪞 Describes a skir enum.
ReflectiveEnumVariant<E>
🪞 Describes a variant in an enum.
ReflectiveEnumWrapperVariant<E, Value>
🪞 Describes an enum wrapper variant. Every instance of this variant wraps around a value of type Value.
ReflectiveOptionalDescriptor<NotNull>
🪞 Describes an optional type that can hold either a value of the wrapped type or null.
ReflectiveRecordDescriptor<T>
🪞 Describes a skir record: struct or enum.
ReflectiveStructDescriptor<Frozen, Mutable>
🪞 Describes a skir struct.
ReflectiveStructField<Frozen, Mutable, Value>
🪞 Describes a field in a struct.
ReflectiveTransformer
🪞 A function object that takes in a skir value of any type and returns a new value of the same type.
ReflectiveTypeDescriptor<T>
🪞 Base class for reflective type descriptors that provide runtime type information.
ReflectiveTypeVisitor<T>
🪞 Visitor for performing type-specific reflective operations on skir types.
RemoteMethodWrapper<Request, Response>
A wrapper around a remote service method that provides invocation.
RequestHandler<RequestMeta>
Unmodifiable view of a Service.
Serializer<T>
Converts objects of type T to and from JSON or binary format.
Serializers
Provides serializers for all primitive types and utilities for creating composite serializers such as optional and iterable serializers.
Service<RequestMeta>
Implementation of a skir RPC service that handles incoming requests.
ServiceClient
Sends RPCs to a skir service.
ServiceOptions<RequestMeta>
Configuration options for a Skir service.
StringDescriptor
🪞 Describes the string primitive type.
StructDescriptor
🪞 Describes a skir struct.
StructField
🪞 Describes a field in a struct.
StructSerializer<Frozen, Mutable>
Specialization of a Serializer for generated struct types.
TimestampDescriptor
🪞 Describes the timestamp primitive type.
TypeDescriptor
🪞 Describes a skir type.
TypeEquivalence<T, U>
🪞 A witness that two types T and U are guaranteed to be identical at runtime, even if Dart's static type checker sees them as different types.

Enums

HttpErrorCode
HTTP status codes for errors.
PrimitiveType
🪞 Enumeration of all primitive types supported by skir.

Constants

internal__listEquality → const ListEquality

Properties

unixEpoch DateTime
The Unix epoch timestamp (January 1, 1970, 00:00:00 UTC).
final

Functions

internal__frozenCopy<E>(Iterable<E> elements) Iterable<E>
internal__frozenMappedCopy<E extends M, M>(Iterable<M> elements, E toFrozen(M)) Iterable<E>
internal__keyedCopy<E, K>(Iterable<E> elements, String getKeySpec, K getKey(E)) KeyedIterable<E, K>
internal__keyedMappedCopy<E extends M, K, M>(Iterable<M> elements, String getKeySpec, K getKey(E), E toFrozen(M)) KeyedIterable<E, K>
internal__stringify<T>(T input, Serializer<T> serializer) String

Exceptions / Errors

RpcException
Exception thrown when an RPC call fails.
ServiceError
If this error is thrown from a method implementation, the specified status code and message will be returned in the HTTP response.