RequestHandler<RequestMeta> class abstract

Unmodifiable view of a Service.

Implementers

Constructors

RequestHandler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleRequest(String requestBody, RequestMeta requestMeta) Future<RawResponse>
Parses the content of a user request and invokes the appropriate method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited