Hash64Descriptor class
🪞 Describes the hash64 primitive type.
- Inheritance
-
- Object
- TypeDescriptor
- PrimitiveDescriptor<
BigInt> - Hash64Descriptor
Properties
-
asJson
→ Map<
String, dynamic> -
Returns the JSON representation of this type descriptor.
no setterinherited
- asJsonCode → String
-
Returns the stringified JSON representation of this type descriptor.
no setterinherited
- defaultValue → BigInt
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- notReflective → PrimitiveDescriptor
-
Returns a non-reflective type descriptor equivalent to this reflective
descriptor.
no setterinherited
- primitiveType → PrimitiveType
-
The specific primitive type being described.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accept(
ReflectiveTypeVisitor< BigInt> visitor) → void -
Accepts a
visitorto perform operations based on the specific skir type: struct, enum, primitive, array, optional.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → Hash64Descriptor
-
final