StructSerializer<Frozen, Mutable> class
Specialization of a Serializer for generated struct types.
- Inheritance
-
- Object
- Serializer<
Frozen> - StructSerializer
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
typeDescriptor
→ ReflectiveStructDescriptor<
Frozen, Mutable> -
The type descriptor that describes
T. Provides reflective information about the type. For structs and enums, it includes field names types, and other metadata useful for introspection and tooling.no setteroverride
Methods
-
fromBytes(
Uint8List bytes, {bool keepUnrecognizedValues = false}) → Frozen -
Deserializes an object from its binary representation.
inherited
-
fromJson(
dynamic json, {bool keepUnrecognizedValues = false}) → Frozen -
Deserializes an object from its JSON representation.
Works with both dense and readable JSON flavors.
inherited
-
fromJsonCode(
String jsonCode, {bool keepUnrecognizedValues = false}) → Frozen -
Deserializes an object from its stringified JSON representation.
Works with both dense and readable JSON flavors.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
Frozen input) → Uint8List -
Converts an object to its binary representation.
inherited
-
toJson(
Frozen input, {bool readableFlavor = false}) → dynamic -
Converts an object to its JSON representation.
If you just need the stringified JSON, call toJsonCode instead.
inherited
-
toJsonCode(
Frozen input, {bool readableFlavor = false}) → String -
Converts an object to its stringified JSON representation.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited