internal__StructSerializerBuilder<Frozen, Mutable> class
Constructors
- internal__StructSerializerBuilder({required String recordId, required String doc, required Frozen defaultInstance, required Mutable newMutable(Frozen?), required Frozen toFrozen(Mutable), required internal__UnrecognizedFields? getUnrecognizedFields(Frozen), required void setUnrecognizedFields(Mutable, internal__UnrecognizedFields)})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serializer
→ StructSerializer<
Frozen, Mutable> -
final
Methods
-
addField<
Value> (String name, String dartName, int number, Serializer< Value> serializer, String doc, Value getter(Frozen), void setter(Mutable, Value)) → void -
addRemovedNumber(
int number) → void -
finalize(
) → void -
mustInitialize(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited